#
# spec file for package python-pelican
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pelican
Version:        4.11.0
Release:        1.1
Summary:        A tool to generate a static blog from reStructuredText or Markdown input files
License:        AGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://getpelican.com/
Source:         https://github.com/getpelican/pelican/archive/refs/tags/%{version}.tar.gz#/pelican-%{version}-gh.tar.gz
BuildRequires:  %{python_module Jinja2 >= 3.1.2}
BuildRequires:  %{python_module Pygments >= 2.16.1}
BuildRequires:  %{python_module Unidecode >= 1.3.7}
BuildRequires:  %{python_module base >= 3.8.1}
BuildRequires:  %{python_module blinker >= 1.7.0}
BuildRequires:  %{python_module docutils >= 0.20.1}
BuildRequires:  %{python_module feedgenerator >= 2.1.0}
BuildRequires:  %{python_module ordered-set >= 4.1.0}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pdm}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-dateutil >= 2.8.2}
BuildRequires:  %{python_module rich >= 13.6.0}
BuildRequires:  %{python_module watchfiles >= 0.21.0}
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  pandoc
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2 >= 3.1.2
Requires:       python-Pygments >= 2.16.1
Requires:       python-Unidecode >= 1.3.7
Requires:       python-blinker >= 1.7.0
Requires:       python-docutils >= 0.20.1
Requires:       python-feedgenerator >= 2.1.0
Requires:       python-ordered-set >= 4.1.0
Requires:       python-python-dateutil >= 2.8.2
Requires:       python-rich >= 13.6.0
Requires:       python-watchfiles >= 0.21.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     make
Suggests:       asciidoc
Suggests:       python-Markdown >= 3.5.1
Suggests:       python-typogrify >= 2.1.0
BuildArch:      noarch
ExcludeArch:    %{ix86}
# SECTION test
BuildRequires:  %{python_module Markdown >= 3.5.1}
BuildRequires:  %{python_module Sphinx >= 7.1.2}
BuildRequires:  %{python_module beautifulsoup4 >= 4.12.2}
BuildRequires:  %{python_module invoke >= 2.2.0}
BuildRequires:  %{python_module livereload >= 2.6.3}
BuildRequires:  %{python_module lxml >= 4.9.3}
BuildRequires:  %{python_module psutil >= 5.9.6}
BuildRequires:  %{python_module pytest >= 7.4.3}
BuildRequires:  %{python_module pytest-cov >= 4.1.0}
BuildRequires:  %{python_module pytest-sugar >= 0.9.7}
BuildRequires:  %{python_module pytest-xdist >= 3.4.0}
BuildRequires:  %{python_module tomli >= 2.0.1 if %python_base < 3.11}
BuildRequires:  %{python_module typogrify >= 2.1.0}
# /SECTION
%python_subpackages

%description
Pelican is a static site generator, written in Python.

* Write your weblog entries directly with your editor of choice in reStructuredText, Markdown or AsciiDoc
* Includes a simple CLI tool to (re)generate the weblog
* Easy to interface with DVCSes and web hooks
* Completely static output is easy to host anywhere

Pelican currently supports:

* Blog articles and pages
* Comments, via an external service
* Theming support (themes are created using Jinja2 templates)
* PDF generation of the articles/pages (optional)
* Publication of articles in multiple languages
* Atom/RSS feeds
* Code syntax highlighting
* Asset management with webassets (optional)
* Import from WordPress, Dotclear, or RSS feeds
* Integration with external tools: Twitter, Google Analytics, etc. (optional)

%prep
%autosetup -p1 -n pelican-%{version}

# remove useless shebang
sed -i '1d' \
    pelican/tools/pelican_import.py \
    pelican/tools/pelican_themes.py \
    pelican/tools/pelican_quickstart.py
# remove executable bit, this is not a script
chmod -x \
    pelican/tools/pelican_import.py \
    pelican/tools/pelican_themes.py \
    pelican/tools/pelican_quickstart.py \
    pelican/tools/templates/publishconf.py.jinja2

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

for p in pelican pelican-import pelican-plugins pelican-quickstart pelican-themes; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

%check
export LC_ALL=C.utf8
export PYTHONPATH=.
# gh#getpelican/pelican#2846
%pytest -k 'not (test_basic_generation_works or test_custom_generation_works or test_custom_locale_generation_works)'

%post
%python_install_alternative pelican pelican-import pelican-plugins pelican-quickstart pelican-themes

%postun
%python_uninstall_alternative pelican

%files %{python_files}
%license LICENSE
%doc CONTRIBUTING.rst README.rst THANKS docs/*
%python_alternative %{_bindir}/pelican
%python_alternative %{_bindir}/pelican-import
%python_alternative %{_bindir}/pelican-plugins
%python_alternative %{_bindir}/pelican-quickstart
%python_alternative %{_bindir}/pelican-themes
%{python_sitelib}/pelican
%{python_sitelib}/pelican-*.dist-info

%changelog
* Thu Jan 16 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.11.0:
  * Add setting to selectively omit Typogrify filters (#3439)
  * Add more blocks to the Simple theme’s base template, making it
    easier to create new themes by inheriting from the Simple theme
    (#3405)
  * Fix auto-reload behavior upon changes to the theme, content or
    settings. Make default IGNORE_FILES recursively ignore all
    hidden files as well as the default filters from
    watchfiles.DefaultFilter. (#3441)
  * Get current year from the SOURCE_DATE_EPOCH environment
    variable, if available (#3430)
  * Add Python 3.13 to test matrix and remove Python 3.8 (#3435)
  * Require Typogrify 2.1+ and Pygments <2.19
- increase the minimum version of typogrify to 2.1.0
* Thu Nov 28 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.10.2:
  * Change IGNORE_FILES setting default to ignore all hidden files
  * Fix SUMMARY_MAX_PARAGRAPHS not being respected in some
    combinations with SUMMARY_MAX_LENGTH
* Sat Sep 28 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.10.1:
  * Fix error when running pelican -r -l
  * Fix symlink handling in pelican-themes
- add build dependency python-pdm-backend
* Mon Sep 16 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.10.0:
  * Add setting to specify summary via paragraph count
  * Add new status to skip generation of a post
  * Add setting to append ref parameter to links in feeds
  * Configure logging handler via --log-handler CLI option
  * Resolve intra-site links in summaries
  * Warn when files are not processed due to disabled readers
  * Add Medium post importer
  * Improve GitHub Pages workflow
  * Improve code test coverage
  * Translate documentation into Simplified Chinese
* Fri Dec  1 2023 Matej Cepl <mcepl@cepl.eu>
- Add Recommends: make
* Sun Nov 26 2023 Dirk Müller <dmueller@suse.com>
- reference github tarball
- cleanup dependencies
* Sun Nov 19 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.9.1:
  * Ensure tzdata dependency is installed on Windows
- additional changes from 4.9.0:
  * Upgrade code to new minimum supported Python version: 3.8
  * Settings support for pathlib.Path (#2758)
  * Various improvements to Simple theme (#2976 & #3234)
  * Use Furo as Sphinx documentation theme (#3023)
  * Default to 100 articles maximum in feeds (#3127)
  * Add period_archives common context variable (#3148)
  * Use watchfiles as the file-watching backend (#3151)
  * Add GitHub Actions workflow for GitHub Pages (#3189)
  * Allow dataclasses in settings (#3204)
  * Switch build tool to PDM instead of Setuptools/Poetry (#3220)
  * Provide a plugin_enabled Jinja test for themes (#3235)
  * Preserve connection order in Blinker (#3238)
  * Remove social icons from default notmyidea theme (#3240)
  * Remove unreliable WRITE_SELECTED feature (#3243)
  * Importer: Report broken embedded video links when importing
    from Tumblr (#3177)
  * Importer: Remove newline addition when iterating Photo post
    types (#3178)
  * Importer: Force timestamp conversion in Tumblr importer to be
    UTC with offset (#3221)
  * Importer: Use tempfile for intermediate HTML file for Pandoc
    (#3221)
  * Switch linters to Ruff (#3223)
- drop python-311.patch: fixed upstream
- update BuildRequires and Requires to match upstream requirements
- switch build to pdm
* Wed Mar  1 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch to support python 3.11
  gh#getpelican/pelican#3055
* Fri Jul 15 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.8.0:
  * Use JSON values for extra settings in Invoke tasks template
    (#2994)
  * Add content tag for links, which can help with things like
    Twitter social cards (#3001)
  * Improve word count behavior when generating summary (#3002)
* Fri Apr 29 2022 Markéta Machová <mmachova@suse.com>
- do not require pytest-pythonpath
* Wed Feb  9 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.7.2:
  * Fix incorrect parsing of parameters specified via
  - e / --extra-settings option flags (#2938)
  * Add categories.html template to default theme (#2973)
  * Document how to use plugins to inject content (#2922)
- do not remove the shebang from jinja templates: fixed upstream
* Sun Oct 24 2021 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to version 4.7.1:
  * Extend rich logging to server component (#2927)
  * Fix an issue where metadata flagged to be discarded was being cached (#2926)
  * Adjust suffix in server to allow redirection when needed (#2931)
  * Add MIME types for web fonts (#2929)
  * Distribute sample data used to run tests (#2935)
  * Add Python 3.10 to test matrix
* Thu Oct 21 2021 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to version 4.7.0:
  * Improve default theme rendering on mobile and other small screen devices
  (#2914)
  * Add support for hidden articles (#2866)
  * Improve word count behavior when generating summary CJK & other
  locales (#2864)
  * Add progress spinner during generation (#2869) and richer logging
  (#2897), both via Rich
  * Invoke tasks serve and livereload now auto-open a web browser
  pointing to the locally-served web site (#2764)
  * Support some date format codes used by ISO dates (#2902)
  * Document how to add a new writer (#2901)
* Tue Aug 10 2021 Matej Cepl <mcepl@suse.com>
- Redisable failing tests (gh#getpelican/pelican#2846).
* Tue Aug 10 2021 Matej Cepl <mcepl@suse.com>
- Exclude ix86 arch, as pandoc is not distributed for it.
* Tue Jul 13 2021 mcepl@suse.com
- Update to version 4.6.0+git.1626161722.332be6e5:
  * Support date format codes G, V, and u (used by ISO dates) (#2902)
  * Document how to add a new writer
  * Fix formatting of Jinja example code. Fixes #2884 (#2886)
  * typo fix
  * Update links to Jinja docs. Fixes #2883 (#2885)
  * Allow easy subclassing of Writer
  * Fix failing tests on Jinja 3+
  * Fix FILENAME_METADATA doc to render correctly
  * Add support for hidden articles
  * Add period_num var for period_archives template
  * Add progress spinner animation during generation
  * Update Pelican feature documentation
  * Update contributing docs and Poetry repository URL
  * Update to v2 of `cache` GitHub Action
  * Automatically open browser when Invoke task starts web server (#2764)
  * Strip HTML tags from `notmyidea` page template's title
  * Update tasks.py
  * Release Pelican 4.6.0
  * Prepare release
  * Make Tox & GitHub CI jobs' Python versions match
  * Relax dependency minimum versions
  * [Docs] Fix link to More Categories plugin
  * Clarify ARTICLE_ORDER_BY documentation
  * Improve consistency between Makefile targets & help
  * Update functional test output for Pygments 2.8
  * Update Pygments dev dependency to v2.8
  * Add .yaml file extension to EditorConfig
  * Change FAQ entry to new Tag Cloud plugin repo
  * Make PKG_PATH var in Invoke tasks.py more DRY
  * ignore None return value from get_generators signal
  * livereload task improvements
  * Update functional tests.
  * Use a top (instead of bottom) border in hentry.
- Switch off failing tests (gh#getpelican/pelican#2846).
* Fri Jan 29 2021 mcepl@suse.com
- Update to version 4.5.4+git.1610713159.8bb5f1b7:
  * Drop unsupported Python 3.5 from test matrix
  * Allow latest Python-Markdown to be installed
  * Adjust functional test output for Pygments 2.7.x
  * Allow latest Pygments to be installed
  * Match test output line endings with current rendering
  * Support last page pattern in PAGINATION_PATTERNS
  * Add FAQ re: Atom full-post vs. summary-only feeds
  * Release Pelican 4.5.4
  * Fix typo in the FAQ: steamline --> streamline.
  * add "http://" prefix to ip+port
* Mon Jan  4 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.5.4:
  * Replace plugin definitions in settings with string
    representations after registering, so they can be cached
    correctly (#2828).
* Tue Dec  1 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.5.3:
  * Fix a mistake made in PR #2821
* Sun Nov 22 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.5.2:
  * Improve logging of generators and writer loaders
- drop removal of macos hidden temporary files: fixed upstream
- get the source from github instead of pypi for the tests
- add the build requirements for the tests:
  * python-Markdown
  * python-beautifulsoup4
  * python-lxml
  * python-pytest-xdist
  * python-pytest
  * python-typogrify
  * git-core
- run the tests
* Mon Nov  2 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.5.1:
  * Refactor intra-site link discovery in order to match more
    permissively (#2646)
  * Fix plugins running twice in auto-reload mode (#2817)
  * Add notice to use from pelican import signals instead of
    import pelican.signals (#2805)
- drop removal of macos hidden temporary files: fixed upstream
- remove CONTRIBUTING.rst THANKS and docs from the package:
  not provided any more
- correctly identify the license file
* Fri Aug 28 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.5.0:
  * Add namespace plugin support; list plugins via pelican-plugins
    command
  * Override settings via -e / --extra-settings CLI option flags
  * Add settings for custom Jinja globals and tests
  * Customize article summary ellipsis via SUMMARY_END_MARKER
    setting
  * Customize Typogrify dash handling via new TYPOGRIFY_DASHES
    setting
  * Support Unicode when generating slugs
  * Support Asciidoc .adoc file generation in Pelican importer
  * Improve user experience when pelican --listen web server is
    quit
  * Improve Invoke tasks template
  * Include tests in source distributions
  * Switch CI from Travis to GitHub Actions
  * Remove support for Python 2.7
- disable python2 build: pelican is python 3 only now
- drop fix-python3-incompatibility.patch: fixed upstream
- update dependencies minimal versions
- drop python-six requirement
- remove hidden macos files
- add new binary pelican-plugins
* Fri Oct 18 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.2.0:
  * Support inline SVGs; don't treat titles in SVGs as HTML titles
  * Add category to feeds (in addition to tags)
  * Improve content metadata field docs
  * Add docs for including other Markdown/reST files in content
* Thu Oct 10 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.1.3:
  * Fix quick-start docs regarding pelican --listen
  * Set default listen address to 127.0.0.1
  * Add extra/optional Markdown dependency to setup.py
  * Use correct SSH port syntax for rsync in tasks.py
  * Place all deprecated settings handling together
  * Add related project URLs for display on PyPI
  * Skip some tests on Windows that can't pass due to filesystem
    differences
* Tue Sep 24 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.1.2:
  * Fix pelican.settings.load_source to avoid caching issues
    PR #2621
* Sat Aug 24 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.1.1:
  * Add AutoPub to auto-publish releases on PR merge
  * Add CSS classes for reStructuredText figures
  * Pass argv to Pelican main entrypoint
  * Set default content status to a blank string rather than None
- drop hidden macos files removal: deleted by upstream
* Sun Jul 14 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.1.0:
  * Live browser reload upon changed files (provided via Invoke
    task)
  * Add pyproject.toml, managed by Poetry
  * Support for invoking python -m pelican
  * Add relative source path attribute to content
  * Allow directories in EXTRA_PATH_METADATA
  * Add all_articles variable to period pages (for recent posts
    functionality)
  * Improve debug mode output
  * Remove blank or duplicate summaries from Atom feed
  * Fix bugs in pagination, pelican-import, pelican-quickstart,
    and feed importer
- remove hidden macos files
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 30 2018 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.0.1:
  * Refactor pelican.server logging
  * Fix bug in which all static files were processed as "draft"
  * Bug fixes for Invoke/Makefile automation, Importer, and other
    miscellanea
* Tue Nov 13 2018 Benoît Monin <benoit.monin@gmx.fr>
- update to version 4.0.0:
  * Replace develop_server.sh script with pelican --listen
  * Improved copy/link behavior for large static files (e.g.,
    videos)
  * New {static} syntax to link to static content; content linked
    to by {static} and {attach} is automatically copied over even
    if not in STATIC_PATHS
  * Pages can now have draft status
  * Show current settings via new --print-settings flag
  * All settings for slugs now use {slug} and/or {lang} rather than
    %%s. If %%s-style settings are encountered, Pelican will emit a
    warning and fallback to the default setting.
  * New signals: feed_generated and page_generated_write_page
  * Replace Fabric with Invoke and fabfile.py template with tasks.py
  * Replace PAGINATED_DIRECT_TEMPLATES by PAGINATED_TEMPLATES,
    extending control over pagination to all templates and making
    page size variable
  * Replace SLUG_SUBSTITUTIONS (and friends) by
    SLUG_REGEX_SUBSTITUTIONS for more finegrained control
  * '{base_name}' value in PAGINATION_PATTERNS setting no longer
    strips 'bar' from 'foo/bar.html' (unless 'bar' == 'index').
  * ARTICLE_ORDER_BY and PAGE_ORDER_BY now also affect 1) category,
    tag and author pages 2) feeds 3) draft and hidden articles and
    pages
  * New ARTICLE_TRANSLATION_ID and PAGE_TRANSLATION_ID settings to
    specify metadata attributes used to identify/disable
    translations
  * Make the HTML reader parse multiple occurrences of metadata
    tags as a list
  * New Blogger XML backup importer
  * Wordpress importer now updates file links to point to local
    copies if the files were downloaded with --wp-attach.
  * Importer no longer inserts extra newlines, to prevent breaking
    of HTML attributes.
  * Pelican server now prioritises foo.html and foo/index.html over
    foo/ when resolving foo.
- update paths for shebang and executable bit removal:
  * pelican/tools/templates/publishconf.py.jinja2
  * pelican/tools/templates/pelicanconf.py.jinja2
* Thu Sep 20 2018 mcepl@suse.com
- Add fix-python3-incompatibility.patch with fix for
  gh#getpelican/pelican#2409.
* Mon May  8 2017 benoit.monin@gmx.fr
- convert the package to singlespec
* Thu Jan 12 2017 benoit.monin@gmx.fr
- update to version 3.7.1:
  * Fix locale issues in Quickstart script
  * Specify encoding for README and CHANGELOG in setup.py
* Wed Dec 14 2016 benoit.monin@gmx.fr
- update to version 3.7.0:
  * Atom feeds output <content> in addition to <summary>
  * Atom feeds use <published> for the original publication date
    and <updated> for modifications
  * Simplify Atom feed ID generation and support URL fragments
  * Produce category feeds with category-specific titles
  * RSS feeds now default to summary instead of full content — set
    RSS_FEED_SUMMARY_ONLY = False to revert to previous behavior
  * Replace MD_EXTENSIONS with MARKDOWN setting
  * Replace JINJA_EXTENSIONS with more-robust JINJA_ENVIRONMENT
    setting
  * Improve summary truncation logic to handle special characters
    and tags that span multiple lines, using HTML parser instead
    of regular expressions
  * Include summary when looking for intra-site link substitutions
  * Link to authors and index via {author}name and {index} syntax
  * Override widget names via LINKS_WIDGET_NAME and
    SOCIAL_WIDGET_NAME
  * Add INDEX_SAVE_AS option to override default index.html value
  * Remove PAGES context variable for themes in favor of pages
  * SLUG_SUBSTITUTIONS now accepts 3-tuple elements, allowing URL
    slugs to contain non-alphanumeric characters
  * Tag and category slugs can be controlled with greater
    precision using the TAG_SUBSTITUTIONS and
    CATEGORY_SUBSTITUTIONS settings
  * Author slugs can be controlled with greater precision using
    the AUTHOR_SUBSTITUTIONS setting
  * DEFAULT_DATE can be defined as a string
  * Use mtime instead of ctime when DEFAULT_DATE = 'fs'
  * Add --fatal=errors|warnings option for use with continuous
    integration
  * When using generator-level caching, ensure previously-cached
    files are processed instead of just new files
  * Add Python and Pelican version information to debug output
  * Improve compatibility with Python 3.5
  * Comply with and enforce PEP8 guidelines
  * Replace tables in settings documentation with data:: directives
- additionnal changes from version 3.6.3:
  * Fix permissions issue in release tarball
- update source url to https://files.pythonhosted.org
- update version required for feedgenerator and six
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Thu Aug  6 2015 benoit.monin@gmx.fr
- update to version 3.6.2:
  * Fix installation errors related to Unicode in tests
  * Don't show pagination in notmyidea theme if there's only one
    page
  * Make hidden pages available in context
  * Improve URLWrapper comparison
* Tue Jun 16 2015 benoit.monin@gmx.fr
- update to version 3.6.0:
  * Disable caching by default in order to prevent potential
    confusion
  * Improve caching behavior, replacing pickle with cpickle
  * Allow Markdown or reST content in metadata fields other than
    summary
  * Support semicolon-separated author/tag lists
  * Improve flexibility of article sorting
  * Add --relative-urls argument
  * Support devserver listening on addresses other than localhost
  * Unify HTTP server handlers to pelican.server throughout
  * Handle intra-site links to draft posts
  * Move tag_cloud from core to plugin
  * Load default theme’s external resources via HTTPS
  * Import drafts from WordPress XML
  * Improve support for Windows users
  * Enhance logging and test suite
  * Clean up and refactor codebase
  * New signals: all_generators_finalized and page_writer_finalized
* Sun Nov  9 2014 benoit.monin@gmx.fr
- update to pelican 3.5.0
  * Introduce ARTICLE_ORDER_BY and PAGE_ORDER_BY settings
    to control the order of articles and pages
  * Include time zone information in dates rendered in templates
  * Expose the reader name in the metadata for articles and pages
  * Add the ability to store static files along with content in the
    same directory as articles and pages using {attach} in the path
  * Prevent Pelican from raising an exception when there are
    duplicate pieces of metadata in a Markdown file
  * Introduce the TYPOGRIFY_IGNORE_TAGS setting to add HTML tags
    to be ignored by Typogrify
  * Add the ability to use - in date formats to strip leading zeros
  * Ensure feed generation is correctly disabled during quickstart
    configuration
  * Fix PAGE_EXCLUDES and ARTICLE_EXCLUDES from incorrectly
    matching sub-directories
  * Introduce STATIC_EXCLUDE setting to add static file excludes
  * Fix an issue when using PAGINATION_PATTERNS while RELATIVE_URLS
    is enabled
  * Fix feed generation causing links to use the wrong language for
    month names when using other locales
  * Fix an issue where the authors list in the simple template
    wasn't correctly formatted
  * Fix an issue when parsing non-string URLs from settings
  * Improve consistency of debug and warning messages
* Sat Sep 20 2014 benoit.monin@gmx.fr
- add the requires as buildrequires to guarantee they are available
* Mon Sep 15 2014 benoit.monin@gmx.fr
- update to pelican 3.4.0
  * Speed up content generation via new caching mechanism
  * Add selective post generation (instead of always building
    entire site)
  * Many documentation improvements, including switching to
    prettier RtD theme
  * Add support for multiple content and plugin paths
  * Add :modified: metadata field to complement :date:
  * Add support for multiple authors via new :authors: metadata
    field
  * Watch for changes in static directories when in
    auto-regeneration mode
  * Add filters to limit log output when desired
  * Add language support to drafts
  * Add ``SLUGIFY_SOURCE`` setting to control how post slugs are
    generated
  * Fix many issues relating to locale and encoding
  * Apply Typogrify filter to post summary
  * Preserve file metadata (e.g. time stamps) when copying static
    files to output
  * Move AsciiDoc support from Pelican core into separate plugin
  * Produce inline links instead of reference-style links when
    importing content
  * Improve handling of ``IGNORE_FILES`` setting behavior
  * Properly escape symbol characters in tag names (e.g. C++)
  * Minor tweaks for Python 3.4 compatibility
  * Add several new signals
- add new runtime dependency: python-dateutil
- switch to the real package name for Markdown
- add package documentation
- use update-alternatives for pelican binaries
* Fri Dec 27 2013 benoit.monin@gmx.fr
- switch from distribute to setuptools
- remove useless CFLAGS="%%{optflags}"
* Wed Sep 25 2013 benoit.monin@gmx.fr
- Update to pelican 3.3
  * Add Fabfile so Fabric can be used for workflow automation
    instead of Make
  * OUTPUT_RETENTION setting can be used to preserve metadata
    (e.g., VCS data such as .hg and .git) from being removed from
    output directory
  * Tumblr import
  * Improve logic and consistency when cleaning output folder
  * Improve documentation versioning and release automation
  * Improve pagination flexibility
  * Rename signals for better consistency (some plugins may need
    to be updated)
  * Move metadata extraction from generators to readers; metadata
    extraction no longer article-specific
  * Deprecate FILES_TO_COPY in favor of STATIC_PATHS and
    EXTRA_PATH_METADATA
  * Summaries in Markdown posts no longer include footnotes
  * Remove unnecessary whitespace in output via lstrip_blocks Jinja
    parameter
  * Move PDF generation from core to plugin
  * Replace MARKUP setting with READERS
  * Add warning if img tag is missing alt attribute
  * Add support for {} in relative links syntax, besides ||
  * Add support for {tag} and {category} relative links
  * Add a content_written signal
- Require python-Jinja2 >= 2.7
- Require python-feedgenerator >= 1.6
* Sat Jun  8 2013 benoit.monin@gmx.fr
- update to pelican 3.2.2
* Fri Apr 26 2013 benoit.monin@gmx.fr
- update to pelican 3.2
* Thu Mar 28 2013 benoit.monin@gmx.fr
- suggest additional python packages instead of recommending them
* Thu Mar 28 2013 benoit.monin@gmx.fr
- remove useless shebang in python files
* Wed Mar 27 2013 benoit.monin@gmx.fr
- initial package with version 3.1.1
